# TrackSim.py
### A Python Wrapper for the [TrackSim] API.

All methods are commented, documentated and adequately typehinted.

## Installation

```sh
pip install tracksim
```

<!-- Links -->
[TrackSim]: https://tracksim.app
